# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"laf_from_opencv_kpts": "feature.ipynb",
         "visualize_LAF": "feature.ipynb",
         "opencv_kpts_from_laf": "feature.ipynb",
         "laf_from_opencv_ORB_kpts": "feature.ipynb",
         "laf_from_opencv_SIFT_kpts": "feature.ipynb",
         "opencv_SIFT_kpts_from_laf": "feature.ipynb",
         "opencv_ORB_kpts_from_laf": "feature.ipynb",
         "cv2_matches_from_kornia": "feature.ipynb",
         "kornia_matches_from_cv2": "feature.ipynb",
         "to_numpy_image": "feature.ipynb",
         "epilines_to_start_end_points": "feature.ipynb",
         "draw_LAF_matches": "feature.ipynb",
         "draw_LAF_matches_from_result_dict": "feature.ipynb",
         "draw_LAF_inliers_perspective_repjojected": "feature.ipynb"}

modules = ["feature.py"]

doc_url = "https://ducha-aiki.github.io/kornia_moons/"

git_url = "https://github.com/ducha-aiki/kornia_moons/tree/master/"

def custom_doc_links(name): return None
